# LastFmGet

[![Unit Tests](https://github.com/D3r3k23/LastFmGet/actions/workflows/test.yaml/badge.svg)](https://github.com/D3r3k23/LastFmGet/actions/workflows/test.yaml)

API wrapper for accessing scrobble data from [Last.fm](https://www.last.fm).

### Installation

`pip install lastfmget`

### Example Usage
